# <img src='./res/icon/wolfie.png' card_color='#22a7f0' width='50' height='50' style='vertical-align:bottom'/> Wolfram Alpha
Use Wolfram Alpha for general knowledge questions

![](./wolfie.gif)


## About
Ask general-knowledge queries of your Mycroft device. 
CommonQuery skill for [Wolfram Alpha](https://wolframalpha.com). 
You'll be surprised by how much it knows!

You can also explicitly request to "ask the wolf"

## Examples
* "ask the wolf what is the speed of light"
* "How tall is Mount Everest?"
* "When was The Rocky Horror Picture Show released?"
* "What is Madonna's real name?"
* "What's 18 times 4?"
* "How many inches in a meter?"

## Category
**Information**

## Tags
#wolfram-alpha
#query
#general-knowledge
#information
